@@ -114,7 +114,8 @@ namespace Gwenview
 #define LOG(x) ;
 #endif
 
-static const int PRELOAD_DELAY = 1000;
+static const int BROWSE_PRELOAD_DELAY = 1000;
+static const int VIEW_PRELOAD_DELAY = 100;
 
 static const char* BROWSE_MODE_SIDE_BAR_GROUP = "SideBar-BrowseMode";
 static const char* VIEW_MODE_SIDE_BAR_GROUP = "SideBar-ViewMode";
@@ -176,6 +177,7 @@ struct MainWindow::Private
     bool mStartSlideShowWhenDirListerCompleted;
     SlideShow* mSlideShow;
     Preloader* mPreloader;
+    bool mPreloadDirectionIsForward;
 #ifdef KIPI_FOUND
     KIPIInterface* mKIPIInterface;
 #endif
@@ -290,7 +292,7 @@ struct MainWindow::Private
         // Connect thumbnail view
         connect(mThumbnailView, SIGNAL(indexActivated(QModelIndex)),
                 q, SLOT(slotThumbnailViewIndexActivated(QModelIndex)));
-        connect(mThumbnailView->selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
+        connect(mThumbnailView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
                 q, SLOT(slotSelectionChanged()));
 
         // Connect delegate
@@ -303,8 +305,8 @@ struct MainWindow::Private
                 mGvCore, SLOT(rotateRight(KUrl)));
         connect(delegate, SIGNAL(showDocumentInFullScreenRequested(KUrl)),
                 q, SLOT(showDocumentInFullScreen(KUrl)));
-        connect(delegate, SIGNAL(setDocumentRatingRequested(KUrl, int)),
-                mGvCore, SLOT(setRating(KUrl, int)));
+        connect(delegate, SIGNAL(setDocumentRatingRequested(KUrl,int)),
+                mGvCore, SLOT(setRating(KUrl,int)));
 
         // Connect url navigator
         connect(mUrlNavigator, SIGNAL(urlChanged(KUrl)),
@@ -414,6 +416,8 @@ struct MainWindow::Private
         mGoToLastAction->setToolTip(i18nc("@info:tooltip", "Go to last image"));
         mGoToLastAction->setShortcut(Qt::Key_End);
 
+        mPreloadDirectionIsForward = true;
+
         mGoUpAction = view->addAction(KStandardAction::Up, q, SLOT(goUp()));
 
         action = view->addAction("go_start_page", q, SLOT(showStartMainPage()));
@@ -553,10 +557,10 @@ struct MainWindow::Private
             | MimeTypeUtils::KIND_VIDEO);
         setDirModelShowDirs(true);
 
-        connect(mDirModel, SIGNAL(rowsInserted(QModelIndex, int, int)),
+        connect(mDirModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
                 q, SLOT(slotDirModelNewItems()));
 
-        connect(mDirModel, SIGNAL(rowsRemoved(QModelIndex, int, int)),
+        connect(mDirModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
                 q, SLOT(updatePreviousNextActions()));
         connect(mDirModel, SIGNAL(modelReset()),
                 q, SLOT(updatePreviousNextActions()));
@@ -594,6 +598,7 @@ struct MainWindow::Private
 
     void goTo(int offset)
     {
+        mPreloadDirectionIsForward = offset > 0;
         QModelIndex index = currentIndex();
         index = mDirModel->index(index.row() + offset, 0);
         if (!index.isValid()) {
@@ -1209,7 +1214,8 @@ void MainWindow::slotSelectionChanged()
     d->updateContextDependentComponents();
 
     // Start preloading
-    QTimer::singleShot(PRELOAD_DELAY, this, SLOT(preloadNextUrl()));
+    int preloadDelay = d->mCurrentMainPageId == ViewMainPageId ? VIEW_PRELOAD_DELAY : BROWSE_PRELOAD_DELAY;
+    QTimer::singleShot(preloadDelay, this, SLOT(preloadNextUrl()));
 }
 
 void MainWindow::slotDirModelNewItems()
@@ -1553,7 +1559,8 @@ void MainWindow::preloadNextUrl()
     if (d->mCurrentMainPageId == ViewMainPageId) {
         // If we are in view mode, preload the next url, otherwise preload the
         // selected one
-        index = d->mDirModel->sibling(index.row() + 1, index.column(), index);
+        int offset = d->mPreloadDirectionIsForward ? 1 : -1;
+        index = d->mDirModel->sibling(index.row() + offset, index.column(), index);
         if (!index.isValid()) {
             return;
         }
